@@ -10,7 +10,10 @@ from eve.utils import config
 
 def parse_date(date_str):
     """Parse elastic datetime string."""
-    return arrow.get(date_str).datetime
+    try:
+        return arrow.get(date_str).datetime
+    except TypeError:
+        return arrow.get(date_str[0]).datetime
 
 
 def convert_dates(doc, dates):
@@ -121,12 +124,15 @@ class Elastic(DataLayer):
                 sort_dict = dict([(key, 'asc' if sortdir > 0 else 'desc')])
                 query['sort'].append(sort_dict)
 
-        if req.where:
+        if request.args.get('filter'):
+            # if there is a filter param, use it as is
+            query_filter = json.loads(request.args.get('filter'))
+            query['filter'] = query_filter
+        elif req.where:
+            # or use where as term filter
             where = json.loads(req.where)
             if where:
-                query['filter'] = {
-                    'term': where
-                }
+                query['filter'] = {'term': where}
 
         if req.max_results:
             query['size'] = req.max_results
@@ -155,7 +161,10 @@ class Elastic(DataLayer):
             except es_exceptions.ElasticHttpNotFoundError:
                 return
 
-            if not hit['exists']:
+            if 'exists' in hit and not hit['exists']:
+                return
+
+            if 'found' in hit and not hit['found']:
                 return
 
             doc = hit.get('fields', hit.get('_source', {}))
@@ -215,6 +224,7 @@ class Elastic(DataLayer):
 
     def _parse_hits(self, hits, resource):
         """Parse hits response into documents."""
+        print(hits)
         return ElasticCursor(hits, self._dates(resource))
 
     def _es_args(self, resource, refresh=None):
